==> pocl_1.1.orig.tar.gz: pocl-1.1/lib/kernel/sleef/libm/rename_vec256.h <==
#define xsin Sleef_sind4_u35_intrin
#define xcos Sleef_cosd4_u35_intrin
#define xsincos Sleef_sincosd4_u35_intrin
#define xtan Sleef_tand4_u35_intrin
#define xasin Sleef_asind4_u35_intrin
#define xacos Sleef_acosd4_u35_intrin
#define xatan Sleef_atand4_u35_intrin
#define xatan2 Sleef_atan2d4_u35_intrin
#define xlog Sleef_logd4_u35_intrin
#define xcbrt Sleef_cbrtd4_u35_intrin
#define xsin_u1 Sleef_sind4_u10_intrin
#define xcos_u1 Sleef_cosd4_u10_intrin
#define xsincos_u1 Sleef_sincosd4_u10_intrin
#define xtan_u1 Sleef_tand4_u10_intrin
#define xasin_u1 Sleef_asind4_u10_intrin
#define xacos_u1 Sleef_acosd4_u10_intrin
#define xatan_u1 Sleef_atand4_u10_intrin
#define xatan2_u1 Sleef_atan2d4_u10_intrin
#define xlog_u1 Sleef_logd4_u10_intrin
#define xcbrt_u1 Sleef_cbrtd4_u10_intrin
#define xexp Sleef_expd4_u10_intrin
#define xpow Sleef_powd4_u10_intrin
#define xsinh Sleef_sinhd4_u10_intrin
#define xcosh Sleef_coshd4_u10_intrin
#define xtanh Sleef_tanhd4_u10_intrin
#define xasinh Sleef_asinhd4_u10_intrin
#define xacosh Sleef_acoshd4_u10_intrin
#define xatanh Sleef_atanhd4_u10_intrin
#define xexp2 Sleef_exp2d4_u10_intrin
#define xexp10 Sleef_exp10d4_u10_intrin
#define xexpm1 Sleef_expm1d4_u10_intrin
#define xlog10 Sleef_log10d4_u10_intrin
#define xlog1p Sleef_log1pd4_u10_intrin
#define xsincospi_u05 Sleef_sincospid4_u05_intrin
#define xsincospi_u35 Sleef_sincospid4_u35_intrin
#define xsinpi_u05 Sleef_sinpid4_u05_intrin
#define xcospi_u05 Sleef_cospid4_u05_intrin
#define xldexp Sleef_ldexpd4_intrin
#define xilogb Sleef_ilogbd4_intrin
#define xfma Sleef_fmad4_intrin
#define xsqrt_u05 Sleef_sqrtd4_u05_intrin
#define xsqrt_u35 Sleef_sqrtd4_u35_intrin
#define xhypot_u05 Sleef_hypotd4_u05_intrin
#define xhypot_u35 Sleef_hypotd4_u35_intrin
#define xfabs Sleef_fabsd4_intrin
#define xcopysign Sleef_copysignd4_intrin
#define xfmax Sleef_fmaxd4_intrin
#define xfmin Sleef_fmind4_intrin
#define xfdim Sleef_fdimd4_intrin
#define xtrunc Sleef_truncd4_intrin
#define xfloor Sleef_floord4_intrin
#define xceil Sleef_ceild4_intrin
#define xround Sleef_roundd4_intrin
#define xrint Sleef_rintd4_intrin
#define xnextafter Sleef_nextafterd4_intrin
#define xfrfrexp Sleef_frfrexpd4_intrin
#define xexpfrexp Sleef_expfrexpd4_intrin
#define xfmod Sleef_fmodd4_intrin
#define xmodf Sleef_modfd4_intrin
#define xlgamma_u1 Sleef_lgammad4_u10_intrin
#define xlgamma_r_u1 Sleef_lgamma_rd4_u10_intrin
#define xtgamma_u1 Sleef_tgammad4_u10_intrin
#define xerf_u1 Sleef_erfd4_u10_intrin
#define xerfc_u15 Sleef_erfcd4_u15_intrin

#define xsinf Sleef_sinf8_u35_intrin
#define xcosf Sleef_cosf8_u35_intrin
#define xsincosf Sleef_sincosf8_u35_intrin
#define xtanf Sleef_tanf8_u35_intrin
#define xasinf Sleef_asinf8_u35_intrin
#define xacosf Sleef_acosf8_u35_intrin
#define xatanf Sleef_atanf8_u35_intrin
#define xatan2f Sleef_atan2f8_u35_intrin
#define xlogf Sleef_logf8_u35_intrin
#define xcbrtf Sleef_cbrtf8_u35_intrin
#define xsinf_u1 Sleef_sinf8_u10_intrin
#define xcosf_u1 Sleef_cosf8_u10_intrin
#define xsincosf_u1 Sleef_sincosf8_u10_intrin
#define xtanf_u1 Sleef_tanf8_u10_intrin
#define xasinf_u1 Sleef_asinf8_u10_intrin
#define xacosf_u1 Sleef_acosf8_u10_intrin
#define xatanf_u1 Sleef_atanf8_u10_intrin
#define xatan2f_u1 Sleef_atan2f8_u10_intrin
#define xlogf_u1 Sleef_logf8_u10_intrin
#define xcbrtf_u1 Sleef_cbrtf8_u10_intrin
#define xexpf Sleef_expf8_u10_intrin
#define xpowf Sleef_powf8_u10_intrin
#define xsinhf Sleef_sinhf8_u10_intrin
#define xcoshf Sleef_coshf8_u10_intrin
#define xtanhf Sleef_tanhf8_u10_intrin
#define xasinhf Sleef_asinhf8_u10_intrin
#define xacoshf Sleef_acoshf8_u10_intrin
#define xatanhf Sleef_atanhf8_u10_intrin
#define xexp2f Sleef_exp2f8_u10_intrin
#define xexp10f Sleef_exp10f8_u10_intrin
#define xexpm1f Sleef_expm1f8_u10_intrin
#define xlog10f Sleef_log10f8_u10_intrin
#define xlog1pf Sleef_log1pf8_u10_intrin
#define xsincospif_u05 Sleef_sincospif8_u05_intrin
#define xsincospif_u35 Sleef_sincospif8_u35_intrin
#define xsinpif_u05 Sleef_sinpif8_u05_intrin
#define xcospif_u05 Sleef_cospif8_u05_intrin
#define xldexpf Sleef_ldexpf8_intrin
#define xilogbf Sleef_ilogbf8_intrin
#define xfmaf Sleef_fmaf8_intrin
#define xsqrtf_u05 Sleef_sqrtf8_u05_intrin
#define xsqrtf_u35 Sleef_sqrtf8_u35_intrin
#define xhypotf_u05 Sleef_hypotf8_u05_intrin
#define xhypotf_u35 Sleef_hypotf8_u35_intrin
#define xfabsf Sleef_fabsf8_intrin
#define xcopysignf Sleef_copysignf8_intrin
#define xfmaxf Sleef_fmaxf8_intrin
#define xfminf Sleef_fminf8_intrin
#define xfdimf Sleef_fdimf8_intrin
#define xtruncf Sleef_truncf8_intrin
#define xfloorf Sleef_floorf8_intrin
#define xceilf Sleef_ceilf8_intrin
#define xroundf Sleef_roundf8_intrin
#define xrintf Sleef_rintf8_intrin
#define xnextafterf Sleef_nextafterf8_intrin
#define xfrfrexpf Sleef_frfrexpf8_intrin
#define xexpfrexpf Sleef_expfrexpf8_intrin
#define xfmodf Sleef_fmodf8_intrin
#define xmodff Sleef_modff8_intrin
#define xlgammaf_u1 Sleef_lgammaf8_u10_intrin
#define xlgamma_rf_u1 Sleef_lgamma_rf8_u10_intrin
#define xtgammaf_u1 Sleef_tgammaf8_u10_intrin
#define xerff_u1 Sleef_erff8_u10_intrin
#define xerfcf_u15 Sleef_erfcf8_u15_intrin
/***********************/
#define xlog1p_fast Sleef_log1p_fast_d4_u10_intrin
#define xlog1pf_fast Sleef_log1p_fast_f8_u10_intrin

#define xpown Sleef_pownd4_u10_intrin
#define xpownf Sleef_pownf8_u10_intrin
#define xpowr Sleef_powrd4_u10_intrin
#define xpowrf Sleef_powrf8_u10_intrin

==> pocl_1.4.orig.tar.gz: pocl-1.4/lib/kernel/sleef/libm/rename_vec256.h <==
#define xsin Sleef_sind4_u35_intrin
#define xcos Sleef_cosd4_u35_intrin
#define xsincos Sleef_sincosd4_u35_intrin
#define xtan Sleef_tand4_u35_intrin
#define xasin Sleef_asind4_u35_intrin
#define xacos Sleef_acosd4_u35_intrin
#define xatan Sleef_atand4_u35_intrin
#define xatan2 Sleef_atan2d4_u35_intrin
#define xlog Sleef_logd4_u35_intrin
#define xcbrt Sleef_cbrtd4_u35_intrin
#define xsin_u1 Sleef_sind4_u10_intrin
#define xcos_u1 Sleef_cosd4_u10_intrin
#define xsincos_u1 Sleef_sincosd4_u10_intrin
#define xtan_u1 Sleef_tand4_u10_intrin
#define xasin_u1 Sleef_asind4_u10_intrin
#define xacos_u1 Sleef_acosd4_u10_intrin
#define xatan_u1 Sleef_atand4_u10_intrin
#define xatan2_u1 Sleef_atan2d4_u10_intrin
#define xlog_u1 Sleef_logd4_u10_intrin
#define xcbrt_u1 Sleef_cbrtd4_u10_intrin
#define xexp Sleef_expd4_u10_intrin
#define xpow Sleef_powd4_u10_intrin
#define xsinh Sleef_sinhd4_u10_intrin
#define xcosh Sleef_coshd4_u10_intrin
#define xtanh Sleef_tanhd4_u10_intrin
#define xasinh Sleef_asinhd4_u10_intrin
#define xacosh Sleef_acoshd4_u10_intrin
#define xatanh Sleef_atanhd4_u10_intrin
#define xexp2 Sleef_exp2d4_u10_intrin
#define xexp10 Sleef_exp10d4_u10_intrin
#define xexpm1 Sleef_expm1d4_u10_intrin
#define xlog10 Sleef_log10d4_u10_intrin
#define xlog2 Sleef_log2d4_u10_intrin
#define xlog1p Sleef_log1pd4_u10_intrin
#define xsincospi_u05 Sleef_sincospid4_u05_intrin
#define xsincospi_u35 Sleef_sincospid4_u35_intrin
#define xsinpi_u05 Sleef_sinpid4_u05_intrin
#define xcospi_u05 Sleef_cospid4_u05_intrin
#define xldexp Sleef_ldexpd4_intrin
#define xilogb Sleef_ilogbd4_intrin
#define xfma Sleef_fmad4_intrin
#define xsqrt Sleef_sqrtd4_intrin
#define xsqrt_u05 Sleef_sqrtd4_u05_intrin
#define xsqrt_u35 Sleef_sqrtd4_u35_intrin
#define xhypot_u05 Sleef_hypotd4_u05_intrin
#define xhypot_u35 Sleef_hypotd4_u35_intrin
#define xfabs Sleef_fabsd4_intrin
#define xcopysign Sleef_copysignd4_intrin
#define xfmax Sleef_fmaxd4_intrin
#define xfmin Sleef_fmind4_intrin
#define xfdim Sleef_fdimd4_intrin
#define xtrunc Sleef_truncd4_intrin
#define xfloor Sleef_floord4_intrin
#define xceil Sleef_ceild4_intrin
#define xround Sleef_roundd4_intrin
#define xrint Sleef_rintd4_intrin
#define xnextafter Sleef_nextafterd4_intrin
#define xfrfrexp Sleef_frfrexpd4_intrin
#define xexpfrexp Sleef_expfrexpd4_intrin
#define xfmod Sleef_fmodd4_intrin
#define xmodf Sleef_modfd4_intrin
#define xlgamma_u1 Sleef_lgammad4_u10_intrin
#define xlgamma_r_u1 Sleef_lgamma_rd4_u10_intrin
#define xtgamma_u1 Sleef_tgammad4_u10_intrin
#define xerf_u1 Sleef_erfd4_u10_intrin
#define xerfc_u15 Sleef_erfcd4_u15_intrin

#define xsinf Sleef_sinf8_u35_intrin
#define xcosf Sleef_cosf8_u35_intrin
#define xsincosf Sleef_sincosf8_u35_intrin
#define xtanf Sleef_tanf8_u35_intrin
#define xasinf Sleef_asinf8_u35_intrin
#define xacosf Sleef_acosf8_u35_intrin
#define xatanf Sleef_atanf8_u35_intrin
#define xatan2f Sleef_atan2f8_u35_intrin
#define xlogf Sleef_logf8_u35_intrin
#define xcbrtf Sleef_cbrtf8_u35_intrin
#define xsinf_u1 Sleef_sinf8_u10_intrin
#define xcosf_u1 Sleef_cosf8_u10_intrin
#define xsincosf_u1 Sleef_sincosf8_u10_intrin
#define xtanf_u1 Sleef_tanf8_u10_intrin
#define xasinf_u1 Sleef_asinf8_u10_intrin
#define xacosf_u1 Sleef_acosf8_u10_intrin
#define xatanf_u1 Sleef_atanf8_u10_intrin
#define xatan2f_u1 Sleef_atan2f8_u10_intrin
#define xlogf_u1 Sleef_logf8_u10_intrin
#define xcbrtf_u1 Sleef_cbrtf8_u10_intrin
#define xexpf Sleef_expf8_u10_intrin
#define xpowf Sleef_powf8_u10_intrin
#define xsinhf Sleef_sinhf8_u10_intrin
#define xcoshf Sleef_coshf8_u10_intrin
#define xtanhf Sleef_tanhf8_u10_intrin
#define xasinhf Sleef_asinhf8_u10_intrin
#define xacoshf Sleef_acoshf8_u10_intrin
#define xatanhf Sleef_atanhf8_u10_intrin
#define xexp2f Sleef_exp2f8_u10_intrin
#define xexp10f Sleef_exp10f8_u10_intrin
#define xexpm1f Sleef_expm1f8_u10_intrin
#define xlog10f Sleef_log10f8_u10_intrin
#define xlog2f Sleef_log2f8_u10_intrin
#define xlog1pf Sleef_log1pf8_u10_intrin
#define xsincospif_u05 Sleef_sincospif8_u05_intrin
#define xsincospif_u35 Sleef_sincospif8_u35_intrin
#define xsinpif_u05 Sleef_sinpif8_u05_intrin
#define xcospif_u05 Sleef_cospif8_u05_intrin
#define xldexpf Sleef_ldexpf8_intrin
#define xilogbf Sleef_ilogbf8_intrin
#define xfmaf Sleef_fmaf8_intrin
#define xsqrtf Sleef_sqrtf8_intrin
#define xsqrtf_u05 Sleef_sqrtf8_u05_intrin
#define xsqrtf_u35 Sleef_sqrtf8_u35_intrin
#define xhypotf_u05 Sleef_hypotf8_u05_intrin
#define xhypotf_u35 Sleef_hypotf8_u35_intrin
#define xfabsf Sleef_fabsf8_intrin
#define xcopysignf Sleef_copysignf8_intrin
#define xfmaxf Sleef_fmaxf8_intrin
#define xfminf Sleef_fminf8_intrin
#define xfdimf Sleef_fdimf8_intrin
#define xtruncf Sleef_truncf8_intrin
#define xfloorf Sleef_floorf8_intrin
#define xceilf Sleef_ceilf8_intrin
#define xroundf Sleef_roundf8_intrin
#define xrintf Sleef_rintf8_intrin
#define xnextafterf Sleef_nextafterf8_intrin
#define xfrfrexpf Sleef_frfrexpf8_intrin
#define xexpfrexpf Sleef_expfrexpf8_intrin
#define xfmodf Sleef_fmodf8_intrin
#define xmodff Sleef_modff8_intrin
#define xlgammaf_u1 Sleef_lgammaf8_u10_intrin
#define xlgamma_rf_u1 Sleef_lgamma_rf8_u10_intrin
#define xtgammaf_u1 Sleef_tgammaf8_u10_intrin
#define xerff_u1 Sleef_erff8_u10_intrin
#define xerfcf_u15 Sleef_erfcf8_u15_intrin
/***********************/
#define xlog1p_fast Sleef_log1p_fast_d4_u10_intrin
#define xlog1pf_fast Sleef_log1p_fast_f8_u10_intrin

#define xpown Sleef_pownd4_u10_intrin
#define xpownf Sleef_pownf8_u10_intrin
#define xpowr Sleef_powrd4_u10_intrin
#define xpowrf Sleef_powrf8_u10_intrin
